<?php
/**
 * Initialize icon list save ajax function
 */
add_action( 'wp_ajax_save_oneclick_icon', 'saveOneclickIcons');
/**
 * Initialize icon settings save ajax function
 */
add_action( 'wp_ajax_save_oneclick_icon_settings', 'saveOneclickIconSettings');
/**
 * Initialize global settings save ajax function
 */
add_action( 'wp_ajax_save_oneclick_global_settings', 'saveOneclickGlobalSettings');

/**
 * Admin core class
 */
class oneclickAdminCore {
	public $user_id;
	public $version = ONECLICK_VERSION;
	public $settings;

	// Initialize admin core class
	public function __construct(){
		$this->setUserId();
		//$this->setVersion();
		$this->setSettings();
	}

	/**
	 * Set plugin global settings variable
	 */ 
	public function setSettings(){
		$this->settings = $this->getOneclickGlobalSettings();
	}

	/**
	 * Get icon list data
	 * 
	 * @param string $type Icon type
	 * 
	 * @return array
	 */
	public function getOneclickIcons($type){
		$data = get_user_meta($this->user_id, $type . '_oneclick_icons');
		$array = maybe_unserialize($data);
		if(isset($array[0])){
			return $array[0];
		} else {
			return false;
		}
	}

	/**
	 * Get icon settings data
	 * 
	 * @return array
	 */
	public function getOneclickIconSettings(){
		$data = get_user_meta($this->user_id, 'oneclick_icon_settings');
		$array = maybe_unserialize($data);
		if(isset($array[0])){
			return $array[0];
		} else {
			return false;
		}
	}

	/**
	 * Get global settings
	 *
	 * @return array
	 */
	public function getOneclickGlobalSettings(){
		$data = get_option('oneclick_global_settings');
		return $data;
	}

	/**
	 * Load all materialize icon class
	 * 
	 * @return array
	 */
	public function getIcons(){
		return array(
		'3d_rotation',
		'ac_unit',
		'access_alarm',
		'access_alarms',
		'access_time',
		'accessibility',
		'accessible',
		'account_balance',
		'account_balance_wallet',
		'account_box',
		'account_circle',
		'adb',
		'add',
		'add_a_photo',
		'add_alarm',
		'add_alert',
		'add_box',
		'add_circle',
		'add_circle_outline',
		'add_location',
		'add_shopping_cart',
		'add_to_photos',
		'add_to_queue',
		'adjust',
		'airline_seat_flat',
		'airline_seat_flat_angled',
		'airline_seat_individual_suite',
		'airline_seat_legroom_extra',
		'airline_seat_legroom_normal',
		'airline_seat_legroom_reduced',
		'airline_seat_recline_extra',
		'airline_seat_recline_normal',
		'airplanemode_active',
		'airplanemode_inactive',
		'airplay',
		'airport_shuttle',
		'alarm',
		'alarm_add',
		'alarm_off',
		'alarm_on',
		'album',
		'all_inclusive',
		'all_out',
		'android',
		'announcement',
		'apps',
		'archive',
		'arrow_back',
		'arrow_downward',
		'arrow_drop_down',
		'arrow_drop_down_circle',
		'arrow_drop_up',
		'arrow_forward',
		'arrow_upward',
		'art_track',
		'aspect_ratio',
		'assessment',
		'assignment',
		'assignment_ind',
		'assignment_late',
		'assignment_return',
		'assignment_returned',
		'assignment_turned_in',
		'assistant',
		'assistant_photo',
		'attach_file',
		'attach_money',
		'attachment',
		'audiotrack',
		'autorenew',
		'av_timer',
		'backspace',
		'backup',
		'battery_alert',
		'battery_charging_full',
		'battery_full',
		'battery_std',
		'battery_unknown',
		'beach_access',
		'beenhere',
		'block',
		'bluetooth',
		'bluetooth_audio',
		'bluetooth_connected',
		'bluetooth_disabled',
		'bluetooth_searching',
		'blur_circular',
		'blur_linear',
		'blur_off',
		'blur_on',
		'book',
		'bookmark',
		'bookmark_border',
		'border_all',
		'border_bottom',
		'border_clear',
		'border_color',
		'border_horizontal',
		'border_inner',
		'border_left',
		'border_outer',
		'border_right',
		'border_style',
		'border_top',
		'border_vertical',
		'branding_watermark',
		'brightness_1',
		'brightness_2',
		'brightness_3',
		'brightness_4',
		'brightness_5',
		'brightness_6',
		'brightness_7',
		'brightness_auto',
		'brightness_high',
		'brightness_low',
		'brightness_medium',
		'broken_image',
		'brush',
		'bubble_chart',
		'bug_report',
		'build',
		'burst_mode',
		'business',
		'business_center',
		'cached',
		'cake',
		'call',
		'call_end',
		'call_made',
		'call_merge',
		'call_missed',
		'call_missed_outgoing',
		'call_received',
		'call_split',
		'call_to_action',
		'camera',
		'camera_alt',
		'camera_enhance',
		'camera_front',
		'camera_rear',
		'camera_roll',
		'cancel',
		'card_giftcard',
		'card_membership',
		'card_travel',
		'casino',
		'cast',
		'cast_connected',
		'center_focus_strong',
		'center_focus_weak',
		'change_history',
		'chat',
		'chat_bubble',
		'chat_bubble_outline',
		'check',
		'check_box',
		'check_box_outline_blank',
		'check_circle',
		'chevron_left',
		'chevron_right',
		'child_care',
		'child_friendly',
		'chrome_reader_mode',
		'class',
		'clear',
		'clear_all',
		'close',
		'closed_caption',
		'cloud',
		'cloud_circle',
		'cloud_done',
		'cloud_download',
		'cloud_off',
		'cloud_queue',
		'cloud_upload',
		'code',
		'collections',
		'collections_bookmark',
		'color_lens',
		'colorize',
		'comment',
		'compare',
		'compare_arrows',
		'computer',
		'confirmation_number',
		'contact_mail',
		'contact_phone',
		'contacts',
		'content_copy',
		'content_cut',
		'content_paste',
		'control_point',
		'control_point_duplicate',
		'copyright',
		'create',
		'create_new_folder',
		'credit_card',
		'crop',
		'crop_16_9',
		'crop_3_2',
		'crop_5_4',
		'crop_7_5',
		'crop_din',
		'crop_free',
		'crop_landscape',
		'crop_original',
		'crop_portrait',
		'crop_rotate',
		'crop_square',
		'dashboard',
		'data_usage',
		'date_range',
		'dehaze',
		'delete',
		'delete_forever',
		'delete_sweep',
		'description',
		'desktop_mac',
		'desktop_windows',
		'details',
		'developer_board',
		'developer_mode',
		'device_hub',
		'devices',
		'devices_other',
		'dialer_sip',
		'dialpad',
		'directions',
		'directions_bike',
		'directions_boat',
		'directions_bus',
		'directions_car',
		'directions_railway',
		'directions_run',
		'directions_subway',
		'directions_transit',
		'directions_walk',
		'disc_full',
		'dns',
		'do_not_disturb',
		'do_not_disturb_alt',
		'do_not_disturb_off',
		'do_not_disturb_on',
		'dock',
		'domain',
		'done',
		'done_all',
		'donut_large',
		'donut_small',
		'drafts',
		'drag_handle',
		'drive_eta',
		'dvr',
		'edit',
		'edit_location',
		'eject',
		'email',
		'enhanced_encryption',
		'equalizer',
		'error',
		'error_outline',
		'euro_symbol',
		'ev_station',
		'event',
		'event_available',
		'event_busy',
		'event_note',
		'event_seat',
		'exit_to_app',
		'expand_less',
		'expand_more',
		'explicit',
		'explore',
		'exposure',
		'exposure_neg_1',
		'exposure_neg_2',
		'exposure_plus_1',
		'exposure_plus_2',
		'exposure_zero',
		'extension',
		'face',
		'fast_forward',
		'fast_rewind',
		'favorite',
		'favorite_border',
		'featured_play_list',
		'featured_video',
		'feedback',
		'fiber_dvr',
		'fiber_manual_record',
		'fiber_new',
		'fiber_pin',
		'fiber_smart_record',
		'file_download',
		'file_upload',
		'filter',
		'filter_1',
		'filter_2',
		'filter_3',
		'filter_4',
		'filter_5',
		'filter_6',
		'filter_7',
		'filter_8',
		'filter_9',
		'filter_9_plus',
		'filter_b_and_w',
		'filter_center_focus',
		'filter_drama',
		'filter_frames',
		'filter_hdr',
		'filter_list',
		'filter_none',
		'filter_tilt_shift',
		'filter_vintage',
		'find_in_page',
		'find_replace',
		'fingerprint',
		'first_page',
		'fitness_center',
		'flag',
		'flare',
		'flash_auto',
		'flash_off',
		'flash_on',
		'flight',
		'flight_land',
		'flight_takeoff',
		'flip',
		'flip_to_back',
		'flip_to_front',
		'folder',
		'folder_open',
		'folder_shared',
		'folder_special',
		'font_download',
		'format_align_center',
		'format_align_justify',
		'format_align_left',
		'format_align_right',
		'format_bold',
		'format_clear',
		'format_color_fill',
		'format_color_reset',
		'format_color_text',
		'format_indent_decrease',
		'format_indent_increase',
		'format_italic',
		'format_line_spacing',
		'format_list_bulleted',
		'format_list_numbered',
		'format_paint',
		'format_quote',
		'format_shapes',
		'format_size',
		'format_strikethrough',
		'format_textdirection_l_to_r',
		'format_textdirection_r_to_l',
		'format_underlined',
		'forum',
		'forward',
		'forward_10',
		'forward_30',
		'forward_5',
		'free_breakfast',
		'fullscreen',
		'fullscreen_exit',
		'functions',
		'g_translate',
		'gamepad',
		'games',
		'gavel',
		'gesture',
		'get_app',
		'gif',
		'golf_course',
		'gps_fixed',
		'gps_not_fixed',
		'gps_off',
		'grade',
		'gradient',
		'grain',
		'graphic_eq',
		'grid_off',
		'grid_on',
		'group',
		'group_add',
		'group_work',
		'hd',
		'hdr_off',
		'hdr_on',
		'hdr_strong',
		'hdr_weak',
		'headset',
		'headset_mic',
		'healing',
		'hearing',
		'help',
		'help_outline',
		'high_quality',
		'highlight',
		'highlight_off',
		'history',
		'home',
		'hot_tub',
		'hotel',
		'hourglass_empty',
		'hourglass_full',
		'http',
		'https',
		'image',
		'image_aspect_ratio',
		'import_contacts',
		'import_export',
		'important_devices',
		'inbox',
		'indeterminate_check_box',
		'info',
		'info_outline',
		'input',
		'insert_chart',
		'insert_comment',
		'insert_drive_file',
		'insert_emoticon',
		'insert_invitation',
		'insert_link',
		'insert_photo',
		'invert_colors',
		'invert_colors_off',
		'iso',
		'keyboard',
		'keyboard_arrow_down',
		'keyboard_arrow_left',
		'keyboard_arrow_right',
		'keyboard_arrow_up',
		'keyboard_backspace',
		'keyboard_capslock',
		'keyboard_hide',
		'keyboard_return',
		'keyboard_tab',
		'keyboard_voice',
		'kitchen',
		'label',
		'label_outline',
		'landscape',
		'language',
		'laptop',
		'laptop_chromebook',
		'laptop_mac',
		'laptop_windows',
		'last_page',
		'launch',
		'layers',
		'layers_clear',
		'leak_add',
		'leak_remove',
		'lens',
		'library_add',
		'library_books',
		'library_music',
		'lightbulb_outline',
		'line_style',
		'line_weight',
		'linear_scale',
		'link',
		'linked_camera',
		'list',
		'live_help',
		'live_tv',
		'local_activity',
		'local_airport',
		'local_atm',
		'local_bar',
		'local_cafe',
		'local_car_wash',
		'local_convenience_store',
		'local_dining',
		'local_drink',
		'local_florist',
		'local_gas_station',
		'local_grocery_store',
		'local_hospital',
		'local_hotel',
		'local_laundry_service',
		'local_library',
		'local_mall',
		'local_movies',
		'local_offer',
		'local_parking',
		'local_pharmacy',
		'local_phone',
		'local_pizza',
		'local_play',
		'local_post_office',
		'local_printshop',
		'local_see',
		'local_shipping',
		'local_taxi',
		'location_city',
		'location_disabled',
		'location_off',
		'location_on',
		'location_searching',
		'lock',
		'lock_open',
		'lock_outline',
		'looks',
		'looks_3',
		'looks_4',
		'looks_5',
		'looks_6',
		'looks_one',
		'looks_two',
		'loop',
		'loupe',
		'low_priority',
		'loyalty',
		'mail',
		'mail_outline',
		'map',
		'markunread',
		'markunread_mailbox',
		'memory',
		'menu',
		'merge_type',
		'message',
		'mic',
		'mic_none',
		'mic_off',
		'mms',
		'mode_comment',
		'mode_edit',
		'monetization_on',
		'money_off',
		'monochrome_photos',
		'mood',
		'mood_bad',
		'more',
		'more_horiz',
		'more_vert',
		'motorcycle',
		'mouse',
		'move_to_inbox',
		'movie',
		'movie_creation',
		'movie_filter',
		'multiline_chart',
		'music_note',
		'music_video',
		'my_location',
		'nature',
		'nature_people',
		'navigate_before',
		'navigate_next',
		'navigation',
		'near_me',
		'network_cell',
		'network_check',
		'network_locked',
		'network_wifi',
		'new_releases',
		'next_week',
		'nfc',
		'no_encryption',
		'no_sim',
		'not_interested',
		'note',
		'note_add',
		'notifications',
		'notifications_active',
		'notifications_none',
		'notifications_off',
		'notifications_paused',
		'offline_pin',
		'ondemand_video',
		'opacity',
		'open_in_browser',
		'open_in_new',
		'open_with',
		'pages',
		'pageview',
		'palette',
		'pan_tool',
		'panorama',
		'panorama_fish_eye',
		'panorama_horizontal',
		'panorama_vertical',
		'panorama_wide_angle',
		'party_mode',
		'pause',
		'pause_circle_filled',
		'pause_circle_outline',
		'payment',
		'people',
		'people_outline',
		'perm_camera_mic',
		'perm_contact_calendar',
		'perm_data_setting',
		'perm_device_information',
		'perm_identity',
		'perm_media',
		'perm_phone_msg',
		'perm_scan_wifi',
		'person',
		'person_add',
		'person_outline',
		'person_pin',
		'person_pin_circle',
		'personal_video',
		'pets',
		'phone',
		'phone_android',
		'phone_bluetooth_speaker',
		'phone_forwarded',
		'phone_in_talk',
		'phone_iphone',
		'phone_locked',
		'phone_missed',
		'phone_paused',
		'phonelink',
		'phonelink_erase',
		'phonelink_lock',
		'phonelink_off',
		'phonelink_ring',
		'phonelink_setup',
		'photo',
		'photo_album',
		'photo_camera',
		'photo_filter',
		'photo_library',
		'photo_size_select_actual',
		'photo_size_select_large',
		'photo_size_select_small',
		'picture_as_pdf',
		'picture_in_picture',
		'picture_in_picture_alt',
		'pie_chart',
		'pie_chart_outlined',
		'pin_drop',
		'place',
		'play_arrow',
		'play_circle_filled',
		'play_circle_outline',
		'play_for_work',
		'playlist_add',
		'playlist_add_check',
		'playlist_play',
		'plus_one',
		'poll',
		'polymer',
		'pool',
		'portable_wifi_off',
		'portrait',
		'power',
		'power_input',
		'power_settings_new',
		'pregnant_woman',
		'present_to_all',
		'print',
		'priority_high',
		'public',
		'publish',
		'query_builder',
		'question_answer',
		'queue',
		'queue_music',
		'queue_play_next',
		'radio',
		'radio_button_checked',
		'radio_button_unchecked',
		'rate_review',
		'receipt',
		'recent_actors',
		'record_voice_over',
		'redeem',
		'redo',
		'refresh',
		'remove',
		'remove_circle',
		'remove_circle_outline',
		'remove_from_queue',
		'remove_red_eye',
		'remove_shopping_cart',
		'reorder',
		'repeat',
		'repeat_one',
		'replay',
		'replay_10',
		'replay_30',
		'replay_5',
		'reply',
		'reply_all',
		'report',
		'report_problem',
		'restaurant',
		'restaurant_menu',
		'restore',
		'restore_page',
		'ring_volume',
		'room',
		'room_service',
		'rotate_90_degrees_ccw',
		'rotate_left',
		'rotate_right',
		'rounded_corner',
		'router',
		'rowing',
		'rss_feed',
		'rv_hookup',
		'satellite',
		'save',
		'scanner',
		'schedule',
		'school',
		'screen_lock_landscape',
		'screen_lock_portrait',
		'screen_lock_rotation',
		'screen_rotation',
		'screen_share',
		'sd_card',
		'sd_storage',
		'search',
		'security',
		'select_all',
		'send',
		'sentiment_dissatisfied',
		'sentiment_neutral',
		'sentiment_satisfied',
		'sentiment_very_dissatisfied',
		'sentiment_very_satisfied',
		'settings',
		'settings_applications',
		'settings_backup_restore',
		'settings_bluetooth',
		'settings_brightness',
		'settings_cell',
		'settings_ethernet',
		'settings_input_antenna',
		'settings_input_component',
		'settings_input_composite',
		'settings_input_hdmi',
		'settings_input_svideo',
		'settings_overscan',
		'settings_phone',
		'settings_power',
		'settings_remote',
		'settings_system_daydream',
		'settings_voice',
		'share',
		'shop',
		'shop_two',
		'shopping_basket',
		'shopping_cart',
		'short_text',
		'show_chart',
		'shuffle',
		'signal_cellular_4_bar',
		'signal_cellular_connected_no_internet_4_bar',
		'signal_cellular_no_sim',
		'signal_cellular_null',
		'signal_cellular_off',
		'signal_wifi_4_bar',
		'signal_wifi_4_bar_lock',
		'signal_wifi_off',
		'sim_card',
		'sim_card_alert',
		'skip_next',
		'skip_previous',
		'slideshow',
		'slow_motion_video',
		'smartphone',
		'smoke_free',
		'smoking_rooms',
		'sms',
		'sms_failed',
		'snooze',
		'sort',
		'sort_by_alpha',
		'spa',
		'space_bar',
		'speaker',
		'speaker_group',
		'speaker_notes',
		'speaker_notes_off',
		'speaker_phone',
		'spellcheck',
		'star',
		'star_border',
		'star_half',
		'stars',
		'stay_current_landscape',
		'stay_current_portrait',
		'stay_primary_landscape',
		'stay_primary_portrait',
		'stop',
		'stop_screen_share',
		'storage',
		'store',
		'store_mall_directory',
		'straighten',
		'streetview',
		'strikethrough_s',
		'style',
		'subdirectory_arrow_left',
		'subdirectory_arrow_right',
		'subject',
		'subscriptions',
		'subtitles',
		'subway',
		'supervisor_account',
		'surround_sound',
		'swap_calls',
		'swap_horiz',
		'swap_vert',
		'swap_vertical_circle',
		'switch_camera',
		'switch_video',
		'sync',
		'sync_disabled',
		'sync_problem',
		'system_update',
		'system_update_alt',
		'tab',
		'tab_unselected',
		'tablet',
		'tablet_android',
		'tablet_mac',
		'tag_faces',
		'tap_and_play',
		'terrain',
		'text_fields',
		'text_format',
		'textsms',
		'texture',
		'theaters',
		'thumb_down',
		'thumb_up',
		'thumbs_up_down',
		'time_to_leave',
		'timelapse',
		'timeline',
		'timer',
		'timer_10',
		'timer_3',
		'timer_off',
		'title',
		'toc',
		'today',
		'toll',
		'tonality',
		'touch_app',
		'toys',
		'track_changes',
		'traffic',
		'train',
		'tram',
		'transfer_within_a_station',
		'transform',
		'translate',
		'trending_down',
		'trending_flat',
		'trending_up',
		'tune',
		'turned_in',
		'turned_in_not',
		'tv',
		'unarchive',
		'undo',
		'unfold_less',
		'unfold_more',
		'update',
		'usb',
		'verified_user',
		'vertical_align_bottom',
		'vertical_align_center',
		'vertical_align_top',
		'vibration',
		'video_call',
		'video_label',
		'video_library',
		'videocam',
		'videocam_off',
		'videogame_asset',
		'view_agenda',
		'view_array',
		'view_carousel',
		'view_column',
		'view_comfy',
		'view_compact',
		'view_day',
		'view_headline',
		'view_list',
		'view_module',
		'view_quilt',
		'view_stream',
		'view_week',
		'vignette',
		'visibility',
		'visibility_off',
		'voice_chat',
		'voicemail',
		'volume_down',
		'volume_mute',
		'volume_off',
		'volume_up',
		'vpn_key',
		'vpn_lock',
		'wallpaper',
		'warning',
		'watch',
		'watch_later',
		'wb_auto',
		'wb_cloudy',
		'wb_incandescent',
		'wb_iridescent',
		'wb_sunny',
		'wc',
		'web',
		'web_asset',
		'weekend',
		'whatshot',
		'widgets',
		'wifi',
		'wifi_lock',
		'wifi_tethering',
		'work',
		'wrap_text',
		'youtube_searched_for',
		'zoom_in',
		'zoom_out',
		'zoom_out_map');
	}

	/**
	 * Load all materialize color
	 * 
	 * @return array
	 */
	public function getColors(){
		return array(
			"materialize-red"=>array("base"=>"#e51c23","lighten-5"=>"#fdeaeb","lighten-4"=>"#f8c1c3","lighten-3"=>"#f3989b","lighten-2"=>"#ee6e73","lighten-1"=>"#ea454b","darken-1"=>"#d0181e","darken-2"=>"#b9151b","darken-3"=>"#a21318","darken-4"=>"#8b1014"),
			"red"=>array("base"=>"#F44336","lighten-5"=>"#FFEBEE","lighten-4"=>"#FFCDD2","lighten-3"=>"#EF9A9A","lighten-2"=>"#E57373","lighten-1"=>"#EF5350","darken-1"=>"#E53935","darken-2"=>"#D32F2F","darken-3"=>"#C62828","darken-4"=>"#B71C1C","accent-1"=>"#FF8A80","accent-2"=>"#FF5252","accent-3"=>"#FF1744","accent-4"=>"#D50000"),
			"pink"=>array("base"=>"#e91e63","lighten-5"=>"#fce4ec","lighten-4"=>"#f8bbd0","lighten-3"=>"#f48fb1","lighten-2"=>"#f06292","lighten-1"=>"#ec407a","darken-1"=>"#d81b60","darken-2"=>"#c2185b","darken-3"=>"#ad1457","darken-4"=>"#880e4f","accent-1"=>"#ff80ab","accent-2"=>"#ff4081","accent-3"=>"#f50057","accent-4"=>"#c51162"),
			"purple"=>array("base"=>"#9c27b0","lighten-5"=>"#f3e5f5","lighten-4"=>"#e1bee7","lighten-3"=>"#ce93d8","lighten-2"=>"#ba68c8","lighten-1"=>"#ab47bc","darken-1"=>"#8e24aa","darken-2"=>"#7b1fa2","darken-3"=>"#6a1b9a","darken-4"=>"#4a148c","accent-1"=>"#ea80fc","accent-2"=>"#e040fb","accent-3"=>"#d500f9","accent-4"=>"#aa00ff"),
			"deep-purple"=>array("base"=>"#673ab7","lighten-5"=>"#ede7f6","lighten-4"=>"#d1c4e9","lighten-3"=>"#b39ddb","lighten-2"=>"#9575cd","lighten-1"=>"#7e57c2","darken-1"=>"#5e35b1","darken-2"=>"#512da8","darken-3"=>"#4527a0","darken-4"=>"#311b92","accent-1"=>"#b388ff","accent-2"=>"#7c4dff","accent-3"=>"#651fff","accent-4"=>"#6200ea"),
			"indigo"=>array("base"=>"#3f51b5","lighten-5"=>"#e8eaf6","lighten-4"=>"#c5cae9","lighten-3"=>"#9fa8da","lighten-2"=>"#7986cb","lighten-1"=>"#5c6bc0","darken-1"=>"#3949ab","darken-2"=>"#303f9f","darken-3"=>"#283593","darken-4"=>"#1a237e","accent-1"=>"#8c9eff","accent-2"=>"#536dfe","accent-3"=>"#3d5afe","accent-4"=>"#304ffe"),
			"blue"=>array("base"=>"#2196F3","lighten-5"=>"#E3F2FD","lighten-4"=>"#BBDEFB","lighten-3"=>"#90CAF9","lighten-2"=>"#64B5F6","lighten-1"=>"#42A5F5","darken-1"=>"#1E88E5","darken-2"=>"#1976D2","darken-3"=>"#1565C0","darken-4"=>"#0D47A1","accent-1"=>"#82B1FF","accent-2"=>"#448AFF","accent-3"=>"#2979FF","accent-4"=>"#2962FF"),
			"light-blue"=>array("base"=>"#03a9f4","lighten-5"=>"#e1f5fe","lighten-4"=>"#b3e5fc","lighten-3"=>"#81d4fa","lighten-2"=>"#4fc3f7","lighten-1"=>"#29b6f6","darken-1"=>"#039be5","darken-2"=>"#0288d1","darken-3"=>"#0277bd","darken-4"=>"#01579b","accent-1"=>"#80d8ff","accent-2"=>"#40c4ff","accent-3"=>"#00b0ff","accent-4"=>"#0091ea"),
			"cyan"=>array("base"=>"#00bcd4","lighten-5"=>"#e0f7fa","lighten-4"=>"#b2ebf2","lighten-3"=>"#80deea","lighten-2"=>"#4dd0e1","lighten-1"=>"#26c6da","darken-1"=>"#00acc1","darken-2"=>"#0097a7","darken-3"=>"#00838f","darken-4"=>"#006064","accent-1"=>"#84ffff","accent-2"=>"#18ffff","accent-3"=>"#00e5ff","accent-4"=>"#00b8d4"),
			"teal"=>array("base"=>"#009688","lighten-5"=>"#e0f2f1","lighten-4"=>"#b2dfdb","lighten-3"=>"#80cbc4","lighten-2"=>"#4db6ac","lighten-1"=>"#26a69a","darken-1"=>"#00897b","darken-2"=>"#00796b","darken-3"=>"#00695c","darken-4"=>"#004d40","accent-1"=>"#a7ffeb","accent-2"=>"#64ffda","accent-3"=>"#1de9b6","accent-4"=>"#00bfa5"),
			"green"=>array("base"=>"#4CAF50","lighten-5"=>"#E8F5E9","lighten-4"=>"#C8E6C9","lighten-3"=>"#A5D6A7","lighten-2"=>"#81C784","lighten-1"=>"#66BB6A","darken-1"=>"#43A047","darken-2"=>"#388E3C","darken-3"=>"#2E7D32","darken-4"=>"#1B5E20","accent-1"=>"#B9F6CA","accent-2"=>"#69F0AE","accent-3"=>"#00E676","accent-4"=>"#00C853"),
			"light-green"=>array("base"=>"#8bc34a","lighten-5"=>"#f1f8e9","lighten-4"=>"#dcedc8","lighten-3"=>"#c5e1a5","lighten-2"=>"#aed581","lighten-1"=>"#9ccc65","darken-1"=>"#7cb342","darken-2"=>"#689f38","darken-3"=>"#558b2f","darken-4"=>"#33691e","accent-1"=>"#ccff90","accent-2"=>"#b2ff59","accent-3"=>"#76ff03","accent-4"=>"#64dd17"),
			"lime"=>array("base"=>"#cddc39","lighten-5"=>"#f9fbe7","lighten-4"=>"#f0f4c3","lighten-3"=>"#e6ee9c","lighten-2"=>"#dce775","lighten-1"=>"#d4e157","darken-1"=>"#c0ca33","darken-2"=>"#afb42b","darken-3"=>"#9e9d24","darken-4"=>"#827717","accent-1"=>"#f4ff81","accent-2"=>"#eeff41","accent-3"=>"#c6ff00","accent-4"=>"#aeea00"),
			"yellow"=>array("base"=>"#ffeb3b","lighten-5"=>"#fffde7","lighten-4"=>"#fff9c4","lighten-3"=>"#fff59d","lighten-2"=>"#fff176","lighten-1"=>"#ffee58","darken-1"=>"#fdd835","darken-2"=>"#fbc02d","darken-3"=>"#f9a825","darken-4"=>"#f57f17","accent-1"=>"#ffff8d","accent-2"=>"#ffff00","accent-3"=>"#ffea00","accent-4"=>"#ffd600"),
			"amber"=>array("base"=>"#ffc107","lighten-5"=>"#fff8e1","lighten-4"=>"#ffecb3","lighten-3"=>"#ffe082","lighten-2"=>"#ffd54f","lighten-1"=>"#ffca28","darken-1"=>"#ffb300","darken-2"=>"#ffa000","darken-3"=>"#ff8f00","darken-4"=>"#ff6f00","accent-1"=>"#ffe57f","accent-2"=>"#ffd740","accent-3"=>"#ffc400","accent-4"=>"#ffab00"),
			"orange"=>array("base"=>"#ff9800","lighten-5"=>"#fff3e0","lighten-4"=>"#ffe0b2","lighten-3"=>"#ffcc80","lighten-2"=>"#ffb74d","lighten-1"=>"#ffa726","darken-1"=>"#fb8c00","darken-2"=>"#f57c00","darken-3"=>"#ef6c00","darken-4"=>"#e65100","accent-1"=>"#ffd180","accent-2"=>"#ffab40","accent-3"=>"#ff9100","accent-4"=>"#ff6d00"),
			"deep-orange"=>array("base"=>"#ff5722","lighten-5"=>"#fbe9e7","lighten-4"=>"#ffccbc","lighten-3"=>"#ffab91","lighten-2"=>"#ff8a65","lighten-1"=>"#ff7043","darken-1"=>"#f4511e","darken-2"=>"#e64a19","darken-3"=>"#d84315","darken-4"=>"#bf360c","accent-1"=>"#ff9e80","accent-2"=>"#ff6e40","accent-3"=>"#ff3d00","accent-4"=>"#dd2c00"),
			"brown"=>array("base"=>"#795548","lighten-5"=>"#efebe9","lighten-4"=>"#d7ccc8","lighten-3"=>"#bcaaa4","lighten-2"=>"#a1887f","lighten-1"=>"#8d6e63","darken-1"=>"#6d4c41","darken-2"=>"#5d4037","darken-3"=>"#4e342e","darken-4"=>"#3e2723"),
			"blue-grey"=>array("base"=>"#607d8b","lighten-5"=>"#eceff1","lighten-4"=>"#cfd8dc","lighten-3"=>"#b0bec5","lighten-2"=>"#90a4ae","lighten-1"=>"#78909c","darken-1"=>"#546e7a","darken-2"=>"#455a64","darken-3"=>"#37474f","darken-4"=>"#263238"),
			"grey"=>array("base"=>"#9e9e9e","lighten-5"=>"#fafafa","lighten-4"=>"#f5f5f5","lighten-3"=>"#eeeeee","lighten-2"=>"#e0e0e0","lighten-1"=>"#bdbdbd","darken-1"=>"#757575","darken-2"=>"#616161","darken-3"=>"#424242","darken-4"=>"#212121"),
			"shades"=>array("black"=>"#000000","white"=>"#FFFFFF","transparent"=>"transparent")
		);
	}

	/**
	 * Generate admin menu url from menu item file
	 * 
	 * @param string $menu_item_file Menu item file
	 * @param bool $submenu_as_parent Is children
	 * 
	 * @return array
	 */
	public function getAdminMenuItemUrl( $menu_item_file, $submenu_as_parent = true ) {
		global $menu, $submenu, $self, $parent_file, $submenu_file, $plugin_page, $typenow;
	 
		$admin_is_parent = false;
		$item = '';
		$submenu_item = '';
		$url = '';
	 
		// 1. Check if top-level menu item
		foreach( $menu as $key => $menu_item ) {
			if ( array_keys( $menu_item, $menu_item_file, true ) ) {
				$item = $menu[ $key ];
			}
	 
			if ( $submenu_as_parent && ! empty( $submenu_item ) ) {
				$menu_hook = get_plugin_page_hook( $submenu_item[2], $item[2] );
				$menu_file = $submenu_item[2];
	 
				if ( false !== ( $pos = strpos( $menu_file, '?' ) ) )
					$menu_file = substr( $menu_file, 0, $pos );
				if ( ! empty( $menu_hook ) || ( ( 'index.php' != $submenu_item[2] ) && file_exists( WP_PLUGIN_DIR . "/$menu_file" ) && ! file_exists( ABSPATH . "/wp-admin/$menu_file" ) ) ) {
					$admin_is_parent = true;
					$url = 'admin.php?page=' . $submenu_item[2];
				} else {
					$url = $submenu_item[2];
				}
			}
	 
			elseif ( ! empty( $item[2] ) && current_user_can( $item[1] ) ) {
				$menu_hook = get_plugin_page_hook( $item[2], 'admin.php' );
				$menu_file = $item[2];
	 
				if ( false !== ( $pos = strpos( $menu_file, '?' ) ) )
					$menu_file = substr( $menu_file, 0, $pos );
				if ( ! empty( $menu_hook ) || ( ( 'index.php' != $item[2] ) && file_exists( WP_PLUGIN_DIR . "/$menu_file" ) && ! file_exists( ABSPATH . "/wp-admin/$menu_file" ) ) ) {
					$admin_is_parent = true;
					$url = 'admin.php?page=' . $item[2];
				} else {
					$url = $item[2];
				}
			}
		}
	 
		// 2. Check if sub-level menu item
		if ( ! $item ) {
			$sub_item = '';
			foreach( $submenu as $top_file => $submenu_items ) {
	 
				// Reindex $submenu_items
				$submenu_items = array_values( $submenu_items );
	 
				foreach( $submenu_items as $key => $submenu_item ) {
					if ( array_keys( $submenu_item, $menu_item_file ) ) {
						$sub_item = $submenu_items[ $key ];
						break;
					}
				}
	 
				if ( ! empty( $sub_item ) )
					break;
			}
	 
			// Get top-level parent item
			foreach( $menu as $key => $menu_item ) {
				if ( array_keys( $menu_item, $top_file, true ) ) {
					$item = $menu[ $key ];
					break;
				}
			}
	 
			// If the $menu_item_file parameter doesn't match any menu item, return false
			if ( ! $sub_item )
				return false;
	 
			// Get URL
			$menu_file = $item[2];
	 
			if ( false !== ( $pos = strpos( $menu_file, '?' ) ) )
				$menu_file = substr( $menu_file, 0, $pos );
	 
			// Handle current for post_type=post|page|foo pages, which won't match $self.
			$self_type = ! empty( $typenow ) ? $self . '?post_type=' . $typenow : 'nothing';
			$menu_hook = get_plugin_page_hook( $sub_item[2], $item[2] );
	 
			$sub_file = $sub_item[2];
			if ( false !== ( $pos = strpos( $sub_file, '?' ) ) )
				$sub_file = substr($sub_file, 0, $pos);
	 
			if ( ! empty( $menu_hook ) || ( ( 'index.php' != $sub_item[2] ) && file_exists( WP_PLUGIN_DIR . "/$sub_file" ) && ! file_exists( ABSPATH . "/wp-admin/$sub_file" ) ) ) {
				// If admin.php is the current page or if the parent exists as a file in the plugins or admin dir
				if ( ( ! $admin_is_parent && file_exists( WP_PLUGIN_DIR . "/$menu_file" ) && ! is_dir( WP_PLUGIN_DIR . "/{$item[2]}" ) ) || file_exists( $menu_file ) )
					$url = add_query_arg( array( 'page' => $sub_item[2] ), $item[2] );
				else
					$url = add_query_arg( array( 'page' => $sub_item[2] ), 'admin.php' );
			} else {
				$url = $sub_item[2];
			}
		}
	 
		return esc_url( $url );
	 
	}

	/**
	 * Set current user id
	 */
	public function setUserId(){
		$this->user_id = get_current_user_id();
	}

	/**
	 * Get user roles
	 * 
	 * @return array
	 */
	public function getUserRoles(){
		return wp_roles()->roles;
	}

	/**
	 * Get current user role
	 * 
	 * @return string
	 */
	public function getCurrentUserRoles() {
		if( is_user_logged_in() ) {
			$user = wp_get_current_user();
			$roles = ( array ) $user->roles;

			return $roles[0];
		} else {
			return null;
		}
	}

	/**
	 * Check user access to oneclick menu
	 * 
	 * @return bool
	 */
	public function haveAccess(){
		$current_user_role = $this->getCurrentUserRoles();
		$global_settings = $this->getOneclickGlobalSettings();
		if((isset($global_settings['oneclick_access_admin_' . $current_user_role]) && $global_settings['oneclick_access_admin_' . $current_user_role]) || current_user_can('administrator')){
			return true;
		} else {
			return false;
		}
	}

	/**
	 * Get user ip address
	 * 
	 * @return string
	 */
	public function getOneclickIp(){
		$ipaddress = '';
		if (getenv('HTTP_CLIENT_IP'))
			$ipaddress = getenv('HTTP_CLIENT_IP');
		else if(getenv('HTTP_X_FORWARDED_FOR'))
			$ipaddress = getenv('HTTP_X_FORWARDED_FOR');
		else if(getenv('HTTP_X_FORWARDED'))
			$ipaddress = getenv('HTTP_X_FORWARDED');
		else if(getenv('HTTP_FORWARDED_FOR'))
			$ipaddress = getenv('HTTP_FORWARDED_FOR');
		else if(getenv('HTTP_FORWARDED'))
			$ipaddress = getenv('HTTP_FORWARDED');
		else if(getenv('REMOTE_ADDR'))
			$ipaddress = getenv('REMOTE_ADDR');
		else
			$ipaddress = 'UNKNOWN';
		return $ipaddress;
	}
}

/**
 * AJAX - Save icon list
 * 
 * @param string $_POST['type'] Icon list type
 * @param string $_POST['data'] Icon list
 */
function saveOneclickIcons(){
	$user_id = get_current_user_id();
	if(isset($_POST['type'])){
		$data = array();

		foreach($_POST['data'] as $key => $value){
			$data[sanitize_key($key)] = array(
				"label" => sanitize_text_field($value['label']),
				"menu_type" => sanitize_text_field($value['menu_type']),
				"menu_link" => esc_url_raw($value['menu_link']),
				"icon" => sanitize_text_field($value['icon']),
				"color" => sanitize_text_field($value['color']),
				"status" => sanitize_text_field($value['status'])
			);
		}
		update_user_meta($user_id, sanitize_key($_POST['type']) . '_oneclick_icons', $data);
	}

	wp_send_json_success(__("Successfull save!", "oneclick"));
}

/**
 * AJAX - Save icon settings
 * 
 * @param string $_POST['data'] Icon settings
 */
function saveOneclickIconSettings(){
	$user_id = get_current_user_id();
	$data = array();

	foreach($_POST['data'] as $key => $value){
		if($key == 'oneclick_admin_main_icon' || $key == 'oneclick_frontend_main_icon'){
			$data[sanitize_key($key)] = array(
				'icon' => sanitize_text_field($value['icon']),
				'color' => sanitize_text_field($value['color'])
			);
		} else {
			$data[sanitize_key($key)] = sanitize_text_field($value);
		}
	}
	update_user_meta($user_id, 'oneclick_icon_settings', $data);

	wp_send_json_success(__("Successfull save!", "oneclick"));
}

/**
 * AJAX - Save global settings
 * 
 * @param string $_POST['data'] Global settings
 */
function saveOneclickGlobalSettings(){
	$admin_core = new oneclickAdminCore;
	$data = array();

	foreach($_POST['data'] as $key => $value){
		$data[sanitize_key($key)] = sanitize_text_field($value);
	}
	update_option('oneclick_global_settings', $data);
	
	wp_send_json_success(__("Successfull save!", "oneclick"));
}

