<?php 
/**
 * Admin init class
 */
class oneclickAdminInit {

	public $plugin_path;
	public $plugin_url;

	/**
	 * Initialize oneClick admin settings
	 */
	public function __construct(){
		$this->init();
	}

	public function init(){
		$this->plugin_path = plugin_dir_path( dirname(__FILE__) );
		$this->plugin_url = plugin_dir_url( dirname(__FILE__) );

		require_once($this->plugin_path . 'classes/admin.core.php');

		// Add oneclick scripts to admin header
		add_action('admin_head', array($this, 'addAdminScripts'));
		
		// Load scripts and styles, if the current admin page is the oneClick setting page
		add_action( 'current_screen', array($this, 'isOneclickAdmin'));

		// Create the oneClick admin menu
		add_action('admin_menu', array($this, 'createMenu'));

		// Add oneclick menu to admin page
		add_action('admin_footer', array($this, 'createOneclickMenu'));
	}

	/**
	 * Set multilanguge support in javascript
	 */
	public function addAdminScripts() {
		?>
			<script>
			  var oneclickConfirm = '<?php echo __('Are you sure?', 'oneclick'); ?>';
			</script>
		<?php
	}

	/**
	 * Check the current admin page is oneClick setting page
	 */
	public function isOneclickAdmin(){
		$screen = get_current_screen();
		if($screen->id == 'tools_page_oneclick-settings'){
			add_action( 'admin_enqueue_scripts', array($this, 'addScripts'));
		} else {
			add_action( 'admin_enqueue_scripts', array($this, 'addButtonScripts'));
		}
	}

	/**
	 * Add additional scripts and styles to the oneClick admin page
	 */
	public function addScripts(){
		wp_register_style( 'oneclick_admin_style', $this->plugin_url . 'assets/css/admin.min.css', false, '1.0.0' );
		wp_enqueue_style( 'oneclick_admin_style');
		wp_register_style( 'oneclick_admin_font', 'https://fonts.googleapis.com/icon?family=Material+Icons', false, '1.0.0' );
		wp_enqueue_style( 'oneclick_admin_font');

		wp_register_script('oneclick_theme', $this->plugin_url . 'assets/js/materialize.min.js', array ('jquery'), false, false);
		wp_enqueue_script('oneclick_theme');
		wp_register_script('oneclick_admin_script', $this->plugin_url . 'assets/js/scripts.min.js', array ('jquery'), false, false);
		wp_enqueue_script('oneclick_admin_script');
	}

	public function addButtonScripts(){
		wp_register_style( 'oneclick_admin_style', $this->plugin_url . 'assets/css/style.min.css', false, '1.0.0' );
		wp_enqueue_style( 'oneclick_admin_style');
		wp_register_style( 'oneclick_admin_font', 'https://fonts.googleapis.com/icon?family=Material+Icons', false, '1.0.0' );
		wp_enqueue_style( 'oneclick_admin_font');

		wp_register_script('oneclick_theme', $this->plugin_url . 'assets/js/materialize.min.js', array ('jquery'), false, false);
		wp_enqueue_script('oneclick_theme');
	}

	/**
	 * Create the oneClick setting menu
	 */
	public function createMenu(){
		add_submenu_page( 'tools.php', __('oneClick settings', 'oneclick'), __('oneClick settings',  'oneclick'), 'edit_posts', 'oneclick-settings', array($this, 'getSettings'));
	}

	/**
	 * Load the oneClick settings page content
	 */
	public function getSettings(){
		$admin_core = new oneclickAdminCore();
		require_once($this->plugin_path . 'classes/admin.settings.php');
	}

	/**
	 * Load the oneClick menu in the admin page
	 */
	public function createOneclickMenu(){
		if(is_user_logged_in()){
			$admin_core = new oneclickAdminCore();
			require_once($this->plugin_path . 'classes/admin.menu.php');
		}
	}
}