<?php
/**
 * Frontend core class
 */
class oneclickFrontendCore {
	public $user_id;

	// Initialize frontend core class
	public function __construct(){
		$this->getUserId();
	}
	
	/**
	 * Set user_id variable
	 */
	public function getUserId(){
		$this->user_id = get_current_user_id();
	}
	
	/**
	 * Get icon settings data
	 * 
	 * @return array
	 */
	public function getOneclickIconSettings(){
		$data = get_user_meta($this->user_id, 'oneclick_icon_settings');
		$array = maybe_unserialize($data);
		if(isset($array[0])){
			return $array[0];
		} else {
			return false;
		}
	}

	/**
	 * Get icon list data
	 * 
	 * @return array
	 */
	public function getOneclickIcons(){
		$data = get_user_meta($this->user_id, 'frontend_oneclick_icons');
		$array = maybe_unserialize($data);
		if(isset($array[0])){
			return $array[0];
		} else {
			return false;
		}
	}

	/**
	 * Get post view count
	 * 
	 * @param int $post_id Post id
	 * 
	 * @return int
	 */
	public function getOneclickPostHit($post_id){
		$data = get_post_meta($post_id, 'oneclick_post_hit', true);
		return ($data?$data:0);
	}

	/**
	 * Update post view count
	 * 
	 * @param int $post_id Post id
	 * 
	 */
	public function updateOneclickPostHit($post_id){
		$data = get_post_meta($post_id, 'oneclick_post_hit', true);
		$hit = ($data?$data:0);

		if(isset($_SESSION['oneclick__post'])){
			if($_SESSION['oneclick__post'] != $post_id){
				update_post_meta($post_id, 'oneclick_post_hit', $hit+1);
				$_SESSION['oneclick__post'] = $post_id;
			}
		} else {
			update_post_meta($post_id, 'oneclick_post_hit', $hit+1);
			$_SESSION['oneclick__post'] = $post_id;
		}
	}

	/**
	 * Get global settings
	 *
	 * @return array
	 */
	public function getOneclickGlobalSettings(){
		$data = get_option('oneclick_global_settings');
		return $data;
	}

	/**
	 * Get current user role
	 * 
	 * @return string
	 */
	public function getCurrentUserRoles() {
		if( is_user_logged_in() ) {
			$user = wp_get_current_user();
			$roles = ( array ) $user->roles;
  
			return $roles[0];
		} else {
			return null;
		}
	}

	/**
	 * Check user access to oneclick menu
	 * 
	 * @return bool
	 */
	public function haveAccess(){
		$current_user_role = $this->getCurrentUserRoles();
		$global_settings = $this->getOneclickGlobalSettings();
		if((isset($global_settings['oneclick_access_frontend_' . $current_user_role]) && $global_settings['oneclick_access_frontend_' . $current_user_role]) || current_user_can('administrator')){
			return true;
		} else {
			return false;
		}
	}
}