<?php 
/**
 * Frontend init class
 */
class oneclickFrontendInit {

	public $plugin_path;
	public $plugin_url;

	/**
	 * Initialize oneClick frontend settings
	 */
	public function __construct(){
		$this->init();
	}

	public function init(){
		$this->plugin_path = plugin_dir_path( dirname(__FILE__) );
		$this->plugin_url = plugin_dir_url( dirname(__FILE__) );

		require_once($this->plugin_path . 'classes/frontend.core.php');

		// Add oneclick scripts to frontend
		add_action('wp_enqueue_scripts', array($this, 'addScripts'));

		// Add oneclick menu to frontend
		add_action('wp_footer', array($this, 'createOneclickMenu'));

		// Set admin bar
		add_filter('show_admin_bar', array($this, 'setAdminBar'));

		// Update post view count
		add_filter('wp', array($this, 'updateOneclickPostHit'));
	}

	/**
	 * Add additional scripts and styles to the oneClick frontend
	 */
	public function addScripts(){
		wp_register_style( 'oneclick_style', $this->plugin_url . 'assets/css/style.min.css', false, '1.0.0' );
		wp_enqueue_style( 'oneclick_style');
		wp_register_style( 'oneclick_font', 'https://fonts.googleapis.com/icon?family=Material+Icons', false, '1.0.0' );
		wp_enqueue_style( 'oneclick_font');

		wp_register_script('oneclick_theme', $this->plugin_url . 'assets/js/materialize.min.js', array ('jquery'), false, false);
		wp_enqueue_script('oneclick_theme');
	}

	/**
	 * Load the oneClick menu in the frontend
	 */
	public function createOneclickMenu(){
		if(is_user_logged_in()){
			$core = new oneclickFrontendCore();
			require_once($this->plugin_path . 'classes/frontend.menu.php');
		}
	}

	/**
	 * Set admin bar enable or disable
	 */
	public function setAdminBar(){
		if(is_user_logged_in()){
			$core = new oneclickFrontendCore();
			$settings = $core->getOneclickIconSettings();
			if($settings['oneclick_setting_admin_bar']){
				return true;
			} else {
				return false;
			}
		}
	}

	/**
	 * Update post view countfunction
	 */
	public function updateOneclickPostHit(){
		$core = new oneclickFrontendCore();
		$core->updateOneclickPostHit(get_the_ID());
	}
}